@@ -450,6 +450,10 @@ function exec_dhcp_search($post, &$data, &$result)
             if ($data === false) {
                 return(1);
             }
+        } else {
+            /*  */
+            result_log(OPERATION . ":NG:" . $log_msg);
+            return(1);
         }
     }
 
