@@ -43,8 +43,7 @@ define("SELECT_GROUP_SQL", "SELECT loggroup.group_id, loggroup.group_name, login
 define("SELECT_FACILITY_SQL", "SELECT loginfo.facility_name, loginfo.search_tab, loginfo.app_name " .
                               "FROM loggroup JOIN loginfo ON loggroup.log_id=loginfo.log_id WHERE group_id=%s;");
 define("MAIL_SEARCH_SQL",   "SELECT DeviceReportedTime, FromHost, Message " .
-                            "FROM %s " .
-                            "AND FromHost IN (SELECT hosts.host_name From hosts JOIN search_hosts on hosts.host_id=search_hosts.host_id WHERE group_id=%s)" .
+                            "FROM %s %s" .
                             " ORDER BY DeviceReportedTime desc LIMIT %s ;");
 
 /*********************************************************
@@ -653,7 +652,10 @@ function exec_mail_search($post)
     if ($web_conf['sylas']['searchtype'] === MYSQL) {
 
         /*MailSQL*/
-        make_mail_search_sql($post, $search_sql, $conn);
+        if(make_mail_search_sql($post, $search_sql, $conn) === FALSE) {
+            mysqli_close($conn);
+            return(1);
+        }
 
         /*MySQL*/
         $result = MySQL_exec_query($conn, $search_sql);
@@ -703,6 +705,10 @@ function exec_mail_search($post)
             if ($data === false) {
                 return(1);
             }
+        } else {
+            /*  */
+            result_log(OPERATION . ":NG:" . $log_msg);
+            return(1);
         }
     }
 
@@ -838,16 +844,62 @@ function exec_mail_search($post)
 function make_mail_search_sql($post, &$sql, $conn)
 {
     global $web_conf;
+    global $msgarr;
+    global $err_msg;
+    global $log_msg;
     
     /**/ 
     $end = "";
     $start = "";
-    $search_time = "";
     $check_count = $web_conf['sylas']['maxsearchcount'] + 1;
     $search_sql = array();
     $facility_arr = array();
     $app_name = "";
 
+
+    $mysql_facilitynumbers = array(
+                         "kern"     => 0,
+                         "user"     => 1,
+                         "mail"     => 2,
+                         "daemon"   => 3,
+                         "auth"     => 4,
+                         "security" => 4,
+                         "syslog"   => 5,
+                         "lpr"      => 6,
+                         "news"     => 7,
+                         "uucp"     => 8,
+                         "cron"     => 9,
+                         "authpriv" => 10,
+                         "ftp"      => 11,
+                         "local0"   => 16,
+                         "local1"   => 17,
+                         "local2"   => 18,
+                         "local3"   => 19,
+                         "local4"   => 20,
+                         "local5"   => 21,
+                         "local6"   => 22,
+                         "local7"   => 23);
+
+    $sql_str = sprintf(ESL_LOGGROUP_SQL,$post["loggroup"]); 
+    $ret = get_data($sql_str, $data);
+    if ($ret === FALSE) {
+        return FALSE;
+    }
+    /* ǡʤȤ롼פ˸оݥۥȤꤵƤʤ */
+    if (count($data) === 0) {
+        $err_msg = $msgarr['28019'][SCREEN_MSG];
+        $log_msg = $msgarr['28019'][LOG_MSG];
+        return FALSE;
+    }
+
+    $tmp_sql = "";
+   /*ơ֥*/
+   if ($data[0]["search_tab"] === "") {
+       $tab =  mysqli_real_escape_string($conn, $web_conf["sylas"]["defaultsearchtable"]);
+   } else {
+       $tab = mysqli_real_escape_string($conn, $data[0]["search_tab"]);
+   }
+
     /* ־ʬ */
     $start_arr = $post["starttime"];
     $end_arr = $post["endtime"];
@@ -910,42 +962,11 @@ function make_mail_search_sql($post, &$sql, $conn)
         $end = sprintf("DeviceReportedTime <= \"%04d%02d%02d%02d%02d%02d\"", $end_arr[0], $end_arr[1], $end_arr[2], $end_arr[3], $end_arr[4], $end_arr[5]);
     }
     if ($start_arr[0] === "--" && $end_arr[0] !== "--") {
-        $search_time = " WHERE " . $end;
+        $tmp_sql .= " WHERE " . $end;
     } elseif ($start_arr[0] !== "--" && $end_arr[0] === "--") {
-        $search_time = " WHERE " . $start;
+        $tmp_sql .= " WHERE " . $start;
     } elseif ($start_arr[0] !== "--" && $end_arr[0] !== "--") {
-        $search_time = " WHERE " . $start . " AND " . $end;
-    } else {
-        $search_time = "WHERE";
-    }
-
-    $mysql_facilitynumbers = array(
-                         "kern"     => 0,
-                         "user"     => 1,
-                         "mail"     => 2,
-                         "daemon"   => 3,
-                         "auth"     => 4,
-                         "security" => 4,
-                         "syslog"   => 5,
-                         "lpr"      => 6,
-                         "news"     => 7,
-                         "uucp"     => 8,
-                         "cron"     => 9,
-                         "authpriv" => 10,
-                         "ftp"      => 11,
-                         "local0"   => 16,
-                         "local1"   => 17,
-                         "local2"   => 18,
-                         "local3"   => 19,
-                         "local4"   => 20,
-                         "local5"   => 21,
-                         "local6"   => 22,
-                         "local7"   => 23);
-
-    $sql_str = sprintf(SELECT_FACILITY_SQL,$post["loggroup"]); 
-    $ret = get_data($sql_str, $data);
-    if ($ret === FALSE) {
-        return FALSE;
+        $tmp_sql .= " WHERE " . $start . " AND " . $end;
     }
 
     /*եƥ*/
@@ -960,26 +981,41 @@ function make_mail_search_sql($post, &$sql, $conn)
     }
     $facility_values = implode(" OR ", $facility_arr);
     if ($facility_values !== "") {
-       $facility_values = " AND (" . $facility_values . ")";
+        if ($tmp_sql != "") {
+            $tmp_sql .= " AND ";
+        } else {
+            $tmp_sql .= " WHERE ";
+        }
+        $tmp_sql .= "(" . $facility_values . ")";
     }
     
-   /*ơ֥*/
-   if ($data[0]["search_tab"] === "") {
-       $search_tab =  mysqli_real_escape_string($conn, $web_conf["sylas"]["defaultsearchtable"]);
-   } else {
-       $search_tab = mysqli_real_escape_string($conn, $data[0]["search_tab"]);
-   }
-
    /*ץꥱ*/
    if ($data[0]["app_name"] !== "") {
-       $app_name = " AND SysLogTag LIKE \"". mysqli_real_escape_string($conn, $data[0]["app_name"])."%\"";
+       if ($tmp_sql != "") {
+           $tmp_sql .= " AND ";
+       } else {
+           $tmp_sql .= " WHERE ";
+       }
+       $tmp_sql .= "SysLogTag LIKE \"". mysqli_real_escape_string($conn, $data[0]["app_name"])."%\"";
    }
 
-   /*ơ֥ȴ֤ȥեƥȥץꥱ*/
-   $tab_time_facility_app = $search_tab . $search_time . $facility_values. $app_name;   
+
+    foreach ($data as $one_data) {
+        /* ƤΥۥȤꤵƤȤۥȾղäʤ */
+        if ($one_data["host_id"] === "1") {
+            $tmp_sql .= "";
+            break;
+        }
+        if ($tmp_sql != "") {
+            $tmp_sql .= " AND ";
+        } else {
+            $tmp_sql .= " WHERE ";
+        }
+        $tmp_sql .= sprintf("FromHost IN (SELECT hosts.host_name From hosts JOIN search_hosts on hosts.host_id=search_hosts.host_id WHERE group_id=%s)", $post['loggroup']);
+    }
 
    /* SQL */
-   $sql = sprintf(MAIL_SEARCH_SQL, $tab_time_facility_app, $post["loggroup"], $check_count);
+   $sql = sprintf(MAIL_SEARCH_SQL, $tab, $tmp_sql, $check_count);
 
    return;
 }
