@@ -1,11 +1,3 @@
-CREATE TABLE SystemEventsProperties
-(
-        ID int unsigned not null auto_increment primary key,
-        SystemEventID int NULL ,
-        ParamName varchar(255) NULL ,
-        ParamValue text NULL
-);
-
 CREATE TABLE `hosts` (
   `host_id` bigint(20) unsigned NOT NULL auto_increment,
   `host_name` char(64) default NULL,
